==> jc-1.4.0.tar.gz: gnu/java/awt/ComponentDataBlitOp.h <==
// public class gnu.java.awt.ComponentDataBlitOp

// class file dependencies
// @dep_class 3cf552ed49ab3c74 gnu_java_awt_ComponentDataBlitOp
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_ComponentDataBlitOp_H_
#define _JC_gnu_java_awt_ComponentDataBlitOp_H_

// Forward structure declarations
struct _jc_gnu_java_awt_ComponentDataBlitOp$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_geom_Point2D$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_awt_image_WritableRaster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_refs	_jc_gnu_java_awt_ComponentDataBlitOp$sub_refs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs	_jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$refs	_jc_gnu_java_awt_ComponentDataBlitOp$refs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$nonrefs	_jc_gnu_java_awt_ComponentDataBlitOp$nonrefs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$object	_jc_gnu_java_awt_ComponentDataBlitOp$object;

typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$fields_struct	_jc_gnu_java_awt_ComponentDataBlitOp$fields_struct;
typedef const struct _jc_gnu_java_awt_ComponentDataBlitOp$vmethods	_jc_gnu_java_awt_ComponentDataBlitOp$vmethods;
typedef const struct _jc_gnu_java_awt_ComponentDataBlitOp$vtable	_jc_gnu_java_awt_ComponentDataBlitOp$vtable;
typedef const struct _jc_gnu_java_awt_ComponentDataBlitOp$vtype	_jc_gnu_java_awt_ComponentDataBlitOp$vtype;

// Class fields structure
struct _jc_gnu_java_awt_ComponentDataBlitOp$fields_struct {
	struct _jc_gnu_java_awt_ComponentDataBlitOp$object	*INSTANCE;
};
extern _jc_gnu_java_awt_ComponentDataBlitOp$fields_struct _jc_gnu_java_awt_ComponentDataBlitOp$class_fields;

// Constructors
extern void _jc_gnu_java_awt_ComponentDataBlitOp$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *);

// Virtual methods
extern struct _jc_java_awt_image_WritableRaster$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$createCompatibleDestRaster$1cc3a2f3065814d2(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *);
extern struct _jc_java_awt_image_WritableRaster$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$filter$78adc3813529c144(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *);
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$getBounds2D$cf46128fa7dfc931(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *);
extern struct _jc_java_awt_geom_Point2D$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$getPoint2D$789fa93cce009ded(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_geom_Point2D$object *, struct _jc_java_awt_geom_Point2D$object *);
extern struct _jc_java_awt_RenderingHints$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$getRenderingHints$0be4be6006d5c514(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$createCompatibleDestRaster$1cc3a2f3065814d2;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$filter$78adc3813529c144;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$getBounds2D$cf46128fa7dfc931;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$getPoint2D$789fa93cce009ded;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$getRenderingHints$0be4be6006d5c514;

// Static methods
extern void _jc_gnu_java_awt_ComponentDataBlitOp$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_awt_ComponentDataBlitOp$vmethods {
	struct _jc_java_awt_image_WritableRaster$object	*(*createCompatibleDestRaster$1cc3a2f3065814d2)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *);
	struct _jc_java_awt_image_WritableRaster$object	*(*filter$78adc3813529c144)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *);
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds2D$cf46128fa7dfc931)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *);
	struct _jc_java_awt_geom_Point2D$object	*(*getPoint2D$789fa93cce009ded)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_geom_Point2D$object *, struct _jc_java_awt_geom_Point2D$object *);
	struct _jc_java_awt_RenderingHints$object	*(*getRenderingHints$0be4be6006d5c514)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *);
};

// Vtable
struct _jc_gnu_java_awt_ComponentDataBlitOp$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_ComponentDataBlitOp$vmethods	gnu_java_awt_ComponentDataBlitOp;
};

// Vtype
struct _jc_gnu_java_awt_ComponentDataBlitOp$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_ComponentDataBlitOp$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_ComponentDataBlitOp$refs {
    _jc_gnu_java_awt_ComponentDataBlitOp$sub_refs	gnu_java_awt_ComponentDataBlitOp;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_ComponentDataBlitOp$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs	gnu_java_awt_ComponentDataBlitOp;
};

// Object instance structure
struct _jc_gnu_java_awt_ComponentDataBlitOp$object {
	_jc_gnu_java_awt_ComponentDataBlitOp$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_ComponentDataBlitOp$vtype	*vtype;
	_jc_gnu_java_awt_ComponentDataBlitOp$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_ComponentDataBlitOp$vtype _jc_gnu_java_awt_ComponentDataBlitOp$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_ComponentDataBlitOp, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_ComponentDataBlitOp$class_object;

#endif	/* _JC_gnu_java_awt_ComponentDataBlitOp_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/ComponentDataBlitOp.h <==
// public class gnu.java.awt.ComponentDataBlitOp

// class file dependencies
// @dep_class 3cf552ed49ab3c74 gnu_java_awt_ComponentDataBlitOp
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_ComponentDataBlitOp_H_
#define _JC_gnu_java_awt_ComponentDataBlitOp_H_

// Forward structure declarations
struct _jc_gnu_java_awt_ComponentDataBlitOp$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_geom_Point2D$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_awt_image_WritableRaster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_refs	_jc_gnu_java_awt_ComponentDataBlitOp$sub_refs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs	_jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$refs	_jc_gnu_java_awt_ComponentDataBlitOp$refs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$nonrefs	_jc_gnu_java_awt_ComponentDataBlitOp$nonrefs;
typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$object	_jc_gnu_java_awt_ComponentDataBlitOp$object;

typedef struct _jc_gnu_java_awt_ComponentDataBlitOp$fields_struct	_jc_gnu_java_awt_ComponentDataBlitOp$fields_struct;
typedef const struct _jc_gnu_java_awt_ComponentDataBlitOp$vmethods	_jc_gnu_java_awt_ComponentDataBlitOp$vmethods;
typedef const struct _jc_gnu_java_awt_ComponentDataBlitOp$vtable	_jc_gnu_java_awt_ComponentDataBlitOp$vtable;
typedef const struct _jc_gnu_java_awt_ComponentDataBlitOp$vtype	_jc_gnu_java_awt_ComponentDataBlitOp$vtype;

// Class fields structure
struct _jc_gnu_java_awt_ComponentDataBlitOp$fields_struct {
	struct _jc_gnu_java_awt_ComponentDataBlitOp$object	*INSTANCE;
};
extern _jc_gnu_java_awt_ComponentDataBlitOp$fields_struct _jc_gnu_java_awt_ComponentDataBlitOp$class_fields;

// Constructors
extern void _jc_gnu_java_awt_ComponentDataBlitOp$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_image_WritableRaster$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$createCompatibleDestRaster$1cc3a2f3065814d2(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_WritableRaster$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$filter$78adc3813529c144(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$getBounds2D$cf46128fa7dfc931(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_geom_Point2D$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$getPoint2D$789fa93cce009ded(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_geom_Point2D$object *, struct _jc_java_awt_geom_Point2D$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_RenderingHints$object *_jc_gnu_java_awt_ComponentDataBlitOp$method$getRenderingHints$0be4be6006d5c514(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$createCompatibleDestRaster$1cc3a2f3065814d2;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$filter$78adc3813529c144;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$getBounds2D$cf46128fa7dfc931;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$getPoint2D$789fa93cce009ded;
extern _jc_method _jc_gnu_java_awt_ComponentDataBlitOp$method_info$getRenderingHints$0be4be6006d5c514;

// Static methods
extern void _jc_gnu_java_awt_ComponentDataBlitOp$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_ComponentDataBlitOp$vmethods {
	struct _jc_java_awt_image_WritableRaster$object	*(*createCompatibleDestRaster$1cc3a2f3065814d2)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_WritableRaster$object	*(*filter$78adc3813529c144)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds2D$cf46128fa7dfc931)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_image_Raster$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_geom_Point2D$object	*(*getPoint2D$789fa93cce009ded)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *, struct _jc_java_awt_geom_Point2D$object *, struct _jc_java_awt_geom_Point2D$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_RenderingHints$object	*(*getRenderingHints$0be4be6006d5c514)(_jc_env *, struct _jc_gnu_java_awt_ComponentDataBlitOp$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_ComponentDataBlitOp$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_ComponentDataBlitOp$vmethods	gnu_java_awt_ComponentDataBlitOp;
};

// Vtype
struct _jc_gnu_java_awt_ComponentDataBlitOp$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_ComponentDataBlitOp$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_ComponentDataBlitOp$refs {
    _jc_gnu_java_awt_ComponentDataBlitOp$sub_refs	gnu_java_awt_ComponentDataBlitOp;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_ComponentDataBlitOp$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_ComponentDataBlitOp$sub_nonrefs	gnu_java_awt_ComponentDataBlitOp;
};

// Object instance structure
struct _jc_gnu_java_awt_ComponentDataBlitOp$object {
	_jc_gnu_java_awt_ComponentDataBlitOp$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_ComponentDataBlitOp$vtype	*vtype;
	_jc_gnu_java_awt_ComponentDataBlitOp$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_ComponentDataBlitOp$vtype _jc_gnu_java_awt_ComponentDataBlitOp$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_ComponentDataBlitOp, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_ComponentDataBlitOp$class_object;

#endif	/* _JC_gnu_java_awt_ComponentDataBlitOp_H_ */
